#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall
version:              1.42.3
visibility:           public
id:                   dhall-1.42.3-GrvhbkCnyBi2WY7MUkkcgi
key:                  dhall-1.42.3-GrvhbkCnyBi2WY7MUkkcgi
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A configuration language guaranteed to terminate
description:
    Dhall is an explicitly typed configuration language that is not Turing
    complete.  Despite being Turing incomplete, Dhall is a real programming
    language with a type-checker and evaluator.

    Use this library to parse, type-check, evaluate, and pretty-print the Dhall
    configuration language.  This package also includes an executable which
    type-checks a Dhall file and reduces the file to a fully evaluated normal
    form.

    Read "Dhall.Tutorial" to learn how to use this library

category:             Compiler
abi:                  f147653ef9562a65ce9987e33b488568
exposed:              True
exposed-modules:
    Dhall Dhall.Binary Dhall.Context Dhall.Core Dhall.Crypto
    Dhall.Deriving Dhall.Diff Dhall.DirectoryTree Dhall.Format
    Dhall.Freeze Dhall.Import Dhall.Lint Dhall.Main Dhall.Map
    Dhall.Marshal.Decode Dhall.Marshal.Encode Dhall.Optics
    Dhall.Package Dhall.Parser Dhall.Parser.Expression
    Dhall.Parser.Token Dhall.Pretty Dhall.Repl Dhall.Schemas Dhall.Set
    Dhall.Src Dhall.Substitution Dhall.TH Dhall.Tags Dhall.Tutorial
    Dhall.TypeCheck Dhall.Util Dhall.Version

hidden-modules:
    Dhall.DirectoryTree.Types Dhall.Eval Dhall.Import.Types
    Dhall.Import.Headers Dhall.Marshal.Internal Dhall.Normalize
    Dhall.Parser.Combinators Dhall.Pretty.Internal Dhall.Syntax
    Dhall.Syntax.Binding Dhall.Syntax.Chunks Dhall.Syntax.Const
    Dhall.Syntax.Expr Dhall.Syntax.FunctionBinding Dhall.Syntax.Import
    Dhall.Syntax.Instances.Applicative Dhall.Syntax.Instances.Bifunctor
    Dhall.Syntax.Instances.Data Dhall.Syntax.Instances.Eq
    Dhall.Syntax.Instances.Foldable Dhall.Syntax.Instances.Functor
    Dhall.Syntax.Instances.Lift Dhall.Syntax.Instances.Monad
    Dhall.Syntax.Instances.NFData Dhall.Syntax.Instances.Ord
    Dhall.Syntax.Instances.Pretty Dhall.Syntax.Instances.Show
    Dhall.Syntax.Instances.Traversable Dhall.Syntax.MultiLet
    Dhall.Syntax.Operations Dhall.Syntax.RecordField Dhall.Syntax.Types
    Dhall.Syntax.Var Dhall.URL Paths_dhall Dhall.Import.HTTP
    Dhall.Import.Manager

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall
hs-libraries:         HSdhall-1.42.3-GrvhbkCnyBi2WY7MUkkcgi
depends:
    Diff-1.0-4F96IMAnGh7AOlcbsBnTkK
    aeson-2.2.2.0-Fs8lpfl0CTvIUZfvQfMaj3
    aeson-pretty-0.8.11-BXz1I6j9D7dKhSm1GVOg8b
    ansi-terminal-1.1-5MUD2jLYLiA9e4scB8VtNm
    atomic-write-0.2.1.1-5KJW15Cu3BJ6pJhRoHXXdb base-4.18.2.1
    base16-bytestring-1.0.2.0-CpWrlklfSq1B5ZY6mOVw28
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-75BwTjwSfoc3sgy0QhC9q4
    cborg-0.2.10.0-7M8uy0zCT70A4JA5nOXhoe
    cborg-json-0.2.6.0-9m7Dqpdgqfb8c17EL7VOqw containers-0.6.7
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha256-0.11.102.1-8v83Nj3uYaWJeunV7IfbXL
    data-fix-0.3.4-7hd2HcUzeuSB4ZFiM2eK02 deepseq-1.4.8.1
    directory-1.3.8.5 dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
    either-5.0.3-HP9BS99MwrmJilazxTVXaq exceptions-0.10.7
    filepath-1.4.300.1 half-0.3.3-1yHmMBHlTZzFIxUytJPSBi
    hashable-1.4.7.0-7UbNEk44IiMJoszryX1sDf haskeline-0.8.2.1
    http-client-0.7.19-DALlHG22JR86LK61BczJck
    http-client-tls-0.3.6.4-9aLPLbyXiQrLJlGR6hoZq5
    http-types-0.12.4-LNdcYYtCiEAAA2abLyIqKh
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    megaparsec-9.7.1-GpPguTGROHLFp8M4r84ARz
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH mtl-2.3.1
    network-uri-2.6.4.2-Lsaf0h0B6LzHuoHWbm4G86
    optparse-applicative-0.18.1.0-3se4EOVlv606hLWBZRUZg0
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    parsers-0.12.12-F4EPt8XFoWi91eVTHNCrxn
    pretty-simple-4.1.4.0-4fsACMxW3D7EV1XUOkT7yW
    prettyprinter-1.7.1-4whBtEvUR8p9qbdUdtF2iM
    prettyprinter-ansi-terminal-1.1.4-865MUJXhvCzBGwYK8eHW56
    repline-0.4.3.0-8K1qOV9c7aG2gqDtsaBJvy
    scientific-0.3.8.1-7wrrztUTJAME8Zylkxnjb5
    serialise-0.2.6.1-Lhv3tQM01mCEGbmOi3oe5Q template-haskell-2.20.0.0
    text-2.0.2 text-manipulate-0.3.1.0-LsQXAFYae9BL09rgz6TvDE
    text-short-0.1.6.1-8mWaGRwCkHoHiMH7N1mtEQ
    th-lift-instances-0.1.20-36fOd2luvRE2L4ASLwEqzQ time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-HrEOz7uUVHiH6j99wQZ7X5
    unordered-containers-0.2.21-DZIhPqSL0N2YNV8fYQEJ8
    vector-0.13.2.0-746bkLFippyHVcwUkeKsy

haddock-interfaces:   /usr/share/doc/dhall/html/dhall.haddock
haddock-html:         /usr/share/doc/dhall/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

